@@ -1,4 +1,3 @@
-# coding=utf-8
 # Copyright 2020 The HuggingFace Datasets Authors and the TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -22,21 +21,22 @@ import os
 import re
 import shutil
 from dataclasses import dataclass
+from pathlib import Path
 from typing import TYPE_CHECKING, List, Optional, Union
 
 import pyarrow as pa
 import pyarrow.parquet as pq
 
-from datasets.utils.file_utils import DownloadConfig
-
-from .naming import _split_re, filename_for_dataset_split
+from .download.download_config import DownloadConfig
+from .naming import _split_re, filenames_for_dataset_split
 from .table import InMemoryTable, MemoryMappedTable, Table, concat_tables
-from .utils import cached_path, logging
+from .utils import logging
+from .utils.file_utils import cached_path
 
 
 if TYPE_CHECKING:
     from .info import DatasetInfo  # noqa: F401
-    from .splits import Split  # noqa: F401
+    from .splits import Split, SplitInfo  # noqa: F401
 
 
 logger = logging.get_logger(__name__)
@@ -44,7 +44,7 @@ logger = logging.get_logger(__name__)
 HF_GCP_BASE_URL = "https://storage.googleapis.com/huggingface-nlp/cache/datasets"
 
 _SUB_SPEC_RE = re.compile(
-    fr"""
+    rf"""
 ^
  (?P<split>{_split_re[1:-1]})
  (\[
@@ -89,44 +89,67 @@ class FileInstructions:
     file_instructions: List[dict]
 
 
-def make_file_instructions(name, split_infos, instruction, filetype_suffix=None):
+def make_file_instructions(
+    name: str,
+    split_infos: List["SplitInfo"],
+    instruction: Union[str, "ReadInstruction"],
+    filetype_suffix: Optional[str] = None,
+    prefix_path: Optional[str] = None,
+):
     """Returns instructions of the split dict.
 
     Args:
         name: Name of the dataset.
         split_infos: `List[SplitInfo]`, Dataset splits information
         instruction: `ReadInstruction` or `str`
-        filetype_suffix: `Optional[str]` suffix of dataset files, e.g. 'arrow' or 'parquet'
+        filetype_suffix: :obj:`str`, optional suffix of dataset files, e.g. 'arrow' or 'parquet'
 
     Returns:
         file_intructions: FileInstructions instance
     """
     name2len = {info.name: info.num_examples for info in split_infos}
+    name2shard_lengths = {info.name: info.shard_lengths for info in split_infos}
+    name2filenames = {
+        info.name: filenames_for_dataset_split(
+            path=prefix_path,
+            dataset_name=name,
+            split=info.name,
+            filetype_suffix=filetype_suffix,
+            shard_lengths=name2shard_lengths[info.name],
+        )
+        for info in split_infos
+    }
     if not isinstance(instruction, ReadInstruction):
         instruction = ReadInstruction.from_spec(instruction)
     # Create the absolute instruction (per split)
     absolute_instructions = instruction.to_absolute(name2len)
 
-    return _make_file_instructions_from_absolutes(
-        name=name, name2len=name2len, absolute_instructions=absolute_instructions, filetype_suffix=filetype_suffix
-    )
-
-
-def _make_file_instructions_from_absolutes(name, name2len, absolute_instructions, filetype_suffix=None):
-    """Returns the files instructions from the absolute instructions list."""
     # For each split, return the files instruction (skip/take)
     file_instructions = []
     num_examples = 0
     for abs_instr in absolute_instructions:
-        length = name2len[abs_instr.splitname]
-        filename = filename_for_dataset_split(
-            dataset_name=name, split=abs_instr.splitname, filetype_suffix=filetype_suffix
-        )
+        split_length = name2len[abs_instr.splitname]
+        filenames = name2filenames[abs_instr.splitname]
+        shard_lengths = name2shard_lengths[abs_instr.splitname]
         from_ = 0 if abs_instr.from_ is None else abs_instr.from_
-        to = length if abs_instr.to is None else abs_instr.to
-        num_examples += to - from_
-        single_file_instructions = [{"filename": filename, "skip": from_, "take": to - from_}]
-        file_instructions.extend(single_file_instructions)
+        to = split_length if abs_instr.to is None else abs_instr.to
+        if shard_lengths is None:  # not sharded
+            for filename in filenames:
+                num_examples += to - from_
+                file_instructions.append({"filename": filename, "skip": from_, "take": to - from_})
+        else:  # sharded
+            index_start = 0  # Beginning (included) of moving window.
+            index_end = 0  # End (excluded) of moving window.
+            for filename, shard_length in zip(filenames, shard_lengths):
+                index_end += shard_length
+                if from_ < index_end and to > index_start:  # There is something to take.
+                    skip = from_ - index_start if from_ > index_start else 0
+                    take = to - index_start - skip if to < index_end else -1
+                    if take == 0:
+                        continue
+                    file_instructions.append({"filename": filename, "skip": skip, "take": take})
+                    num_examples += shard_length - skip if take == -1 else take
+                index_start += shard_length
     return FileInstructions(
         num_examples=num_examples,
         file_instructions=file_instructions,
@@ -183,7 +206,7 @@ class BaseReader:
     def get_file_instructions(self, name, instruction, split_infos):
         """Return list of dict {'filename': str, 'skip': int, 'take': int}"""
         file_instructions = make_file_instructions(
-            name, split_infos, instruction, filetype_suffix=self._filetype_suffix
+            name, split_infos, instruction, filetype_suffix=self._filetype_suffix, prefix_path=self._path
         )
         files = file_instructions.file_instructions
         return files
@@ -212,7 +235,7 @@ class BaseReader:
         files = self.get_file_instructions(name, instructions, split_infos)
         if not files:
             msg = f'Instruction "{instructions}" corresponds to no data!'
-            raise AssertionError(msg)
+            raise ValueError(msg)
         return self.read_files(files=files, original_instructions=instructions, in_memory=in_memory)
 
     def read_files(
@@ -272,11 +295,12 @@ class BaseReader:
                     split_infos=self._info.splits.values(),
                 )
                 for file_instruction in file_instructions:
-                    remote_prepared_filename = os.path.join(remote_cache_dir, file_instruction["filename"])
+                    file_to_download = str(Path(file_instruction["filename"]).relative_to(self._path))
+                    remote_prepared_filename = os.path.join(remote_cache_dir, file_to_download)
                     downloaded_prepared_filename = cached_path(
                         remote_prepared_filename.replace(os.sep, "/"), download_config=download_config
                     )
-                    shutil.move(downloaded_prepared_filename, os.path.join(self._path, file_instruction["filename"]))
+                    shutil.move(downloaded_prepared_filename, file_instruction["filename"])
         except FileNotFoundError as err:
             raise MissingFilesOnHfGcsError(err) from None
 
@@ -305,6 +329,8 @@ class ArrowReader(BaseReader):
             filename_skip_take["take"] if "take" in filename_skip_take else None,
         )
         table = ArrowReader.read_table(filename, in_memory=in_memory)
+        if take == -1:
+            take = len(table) - skip
         # here we don't want to slice an empty table, or it may segfault
         if skip is not None and take is not None and not (skip == 0 and take == len(table)):
             table = table.slice(skip, take)
@@ -382,11 +408,11 @@ class _RelativeInstruction:
         if self.rounding is not None and self.rounding not in ["closest", "pct1_dropremainder"]:
             raise ValueError("rounding must be either closest or pct1_dropremainder")
         if self.unit != "%" and self.rounding is not None:
-            raise AssertionError("It is forbidden to specify rounding if not using percent slicing.")
+            raise ValueError("It is forbidden to specify rounding if not using percent slicing.")
         if self.unit == "%" and self.from_ is not None and abs(self.from_) > 100:
-            raise AssertionError("Percent slice boundaries must be > -100 and < 100.")
+            raise ValueError("Percent slice boundaries must be > -100 and < 100.")
         if self.unit == "%" and self.to is not None and abs(self.to) > 100:
-            raise AssertionError("Percent slice boundaries must be > -100 and < 100.")
+            raise ValueError("Percent slice boundaries must be > -100 and < 100.")
         # Update via __dict__ due to instance being "frozen"
         self.__dict__["rounding"] = "closest" if self.rounding is None and self.unit == "%" else self.rounding
 
@@ -395,7 +421,7 @@ def _str_to_read_instruction(spec):
     """Returns ReadInstruction for given string."""
     res = _SUB_SPEC_RE.match(spec)
     if not res:
-        raise AssertionError(f"Unrecognized instruction format: {spec}")
+        raise ValueError(f"Unrecognized instruction format: {spec}")
     unit = "%" if res.group("from_pct") or res.group("to_pct") else "abs"
     return ReadInstruction(
         split_name=res.group("split"),
@@ -413,7 +439,7 @@ def _pct_to_abs_pct1(boundary, num_examples):
             'Using "pct1_dropremainder" rounding on a split with less than 100 '
             "elements is forbidden: it always results in an empty dataset."
         )
-        raise AssertionError(msg)
+        raise ValueError(msg)
     return boundary * math.trunc(num_examples / 100.0)
 
 
@@ -443,7 +469,7 @@ def _rel_to_abs_instr(rel_instr, name2len):
         to = num_examples if to is None else to
     if abs(from_) > num_examples or abs(to) > num_examples:
         msg = f'Requested slice [{from_ or ""}:{to or ""}] incompatible with {num_examples} examples.'
-        raise AssertionError(msg)
+        raise ValueError(msg)
     if from_ < 0:
         from_ = num_examples + from_
     elif from_ == 0:
@@ -458,9 +484,7 @@ def _rel_to_abs_instr(rel_instr, name2len):
 class ReadInstruction:
     """Reading instruction for a dataset.
 
-    Examples of usage:
-
-    .. code:: python
+    Examples::
 
       # The following lines are equivalent:
       ds = datasets.load_dataset('mnist', split='test[:33%]')
@@ -539,20 +563,24 @@ class ReadInstruction:
 
     @classmethod
     def from_spec(cls, spec):
-        """Creates a ReadInstruction instance out of a string spec.
+        """Creates a `ReadInstruction` instance out of a string spec.
 
         Args:
-            spec (str): split(s) + optional slice(s) to read + optional rounding
-                        if percents are used as the slicing unit. A slice can be specified,
-                        using absolute numbers (int) or percentages (int). E.g.
-                            `test`: test split.
-                            `test + validation`: test split + validation split.
-                            `test[10:]`: test split, minus its first 10 records.
-                            `test[:10%]`: first 10% records of test split.
-                            `test[:20%](pct1_dropremainder)`: first 10% records, rounded with
-                                                              the `pct1_dropremainder` rounding.
-                            `test[:-5%]+train[40%:60%]`: first 95% of test + middle 20% of
-                                                         train.
+            spec (`str`):
+                Split(s) + optional slice(s) to read + optional rounding
+                if percents are used as the slicing unit. A slice can be specified,
+                using absolute numbers (`int`) or percentages (`int`).
+
+        Examples:
+
+            ```
+            test: test split.
+            test + validation: test split + validation split.
+            test[10:]: test split, minus its first 10 records.
+            test[:10%]: first 10% records of test split.
+            test[:20%](pct1_dropremainder): first 10% records, rounded with the pct1_dropremainder rounding.
+            test[:-5%]+train[40%:60%]: first 95% of test + middle 20% of train.
+            ```
 
         Returns:
             ReadInstruction instance.
@@ -560,9 +588,9 @@ class ReadInstruction:
         spec = str(spec)  # Need to convert to str in case of NamedSplit instance.
         subs = _ADDITION_SEP_RE.split(spec)
         if not subs:
-            raise AssertionError(f"No instructions could be built out of {spec}")
+            raise ValueError(f"No instructions could be built out of {spec}")
         instruction = _str_to_read_instruction(subs[0])
-        return sum([_str_to_read_instruction(sub) for sub in subs[1:]], instruction)
+        return sum((_str_to_read_instruction(sub) for sub in subs[1:]), instruction)
 
     def to_spec(self):
         rel_instr_specs = []
@@ -588,7 +616,7 @@ class ReadInstruction:
         """Returns a new ReadInstruction obj, result of appending other to self."""
         if not isinstance(other, ReadInstruction):
             msg = "ReadInstruction can only be added to another ReadInstruction obj."
-            raise AssertionError(msg)
+            raise TypeError(msg)
         self_ris = self._relative_instructions
         other_ris = other._relative_instructions  # pylint: disable=protected-access
         if (
@@ -596,7 +624,7 @@ class ReadInstruction:
             and other_ris[0].unit != "abs"
             and self._relative_instructions[0].rounding != other_ris[0].rounding
         ):
-            raise AssertionError("It is forbidden to sum ReadInstruction instances with different rounding values.")
+            raise ValueError("It is forbidden to sum ReadInstruction instances with different rounding values.")
         return self._read_instruction_from_relative_instructions(self_ris + other_ris)
 
     def __str__(self):
@@ -611,7 +639,8 @@ class ReadInstruction:
         Those absolute instructions are then to be added together.
 
         Args:
-            name2len: dict associating split names to number of examples.
+            name2len (`dict`):
+                Associating split names to number of examples.
 
         Returns:
             list of _AbsoluteInstruction instances (corresponds to the + in spec).
