@@ -19,6 +19,7 @@ import importlib
 import inspect
 import json
 import os
+import posixpath
 import shutil
 import time
 import warnings
@@ -77,7 +78,7 @@ from .utils.file_utils import (
 )
 from .utils.filelock import FileLock
 from .utils.hub import hf_hub_url
-from .utils.info_utils import is_small_dataset
+from .utils.info_utils import VerificationMode, is_small_dataset
 from .utils.logging import get_logger
 from .utils.metadata import DatasetMetadata
 from .utils.py_utils import get_imports
@@ -217,6 +218,8 @@ def _download_additional_modules(
     if needs_to_be_installed:
         _dependencies_str = "dependencies" if len(needs_to_be_installed) > 1 else "dependency"
         _them_str = "them" if len(needs_to_be_installed) > 1 else "it"
+        if "sklearn" in needs_to_be_installed.keys():
+            needs_to_be_installed["sklearn"] = "scikit-learn"
         raise ImportError(
             f"To be able to use {name}, you need to install the following {_dependencies_str}: "
             f"{', '.join(needs_to_be_installed)}.\nPlease install {_them_str} using 'pip install "
@@ -232,7 +235,7 @@ def _copy_script_and_other_resources_in_importable_dir(
     original_local_path: str,
     local_imports: List[Tuple[str, str]],
     additional_files: List[Tuple[str, str]],
-    download_mode: Optional[DownloadMode],
+    download_mode: Optional[Union[DownloadMode, str]],
 ) -> str:
     """Copy a script and its required imports to an importable directory
 
@@ -243,7 +246,7 @@ def _copy_script_and_other_resources_in_importable_dir(
         original_local_path (str): local path to the resource script
         local_imports (List[Tuple[str, str]]): list of (destination_filename, import_file_to_copy)
         additional_files (List[Tuple[str, str]]): list of (destination_filename, additional_file_to_copy)
-        download_mode (Optional[DownloadMode]): download mode
+        download_mode (Optional[Union[DownloadMode, str]]): download mode
 
     Return:
         importable_local_file: path to an importable module with importlib.import_module
@@ -443,7 +446,7 @@ class GithubMetricModuleFactory(_MetricModuleFactory):
         name: str,
         revision: Optional[Union[str, Version]] = None,
         download_config: Optional[DownloadConfig] = None,
-        download_mode: Optional[DownloadMode] = None,
+        download_mode: Optional[Union[DownloadMode, str]] = None,
         dynamic_modules_path: Optional[str] = None,
     ):
         self.name = name
@@ -517,7 +520,7 @@ class LocalMetricModuleFactory(_MetricModuleFactory):
         self,
         path: str,
         download_config: Optional[DownloadConfig] = None,
-        download_mode: Optional[DownloadMode] = None,
+        download_mode: Optional[Union[DownloadMode, str]] = None,
         dynamic_modules_path: Optional[str] = None,
     ):
         self.path = path
@@ -558,7 +561,7 @@ class LocalDatasetModuleFactoryWithScript(_DatasetModuleFactory):
         self,
         path: str,
         download_config: Optional[DownloadConfig] = None,
-        download_mode: Optional[DownloadMode] = None,
+        download_mode: Optional[Union[DownloadMode, str]] = None,
         dynamic_modules_path: Optional[str] = None,
     ):
         self.path = path
@@ -609,7 +612,7 @@ class LocalDatasetModuleFactoryWithoutScript(_DatasetModuleFactory):
         path: str,
         data_dir: Optional[str] = None,
         data_files: Optional[Union[str, List, Dict]] = None,
-        download_mode: Optional[DownloadMode] = None,
+        download_mode: Optional[Union[DownloadMode, str]] = None,
     ):
         if data_dir and os.path.isabs(data_dir):
             raise ValueError(f"`data_dir` must be relative to a dataset directory's root: {path}")
@@ -689,9 +692,8 @@ class PackagedDatasetModuleFactory(_DatasetModuleFactory):
         data_dir: Optional[str] = None,
         data_files: Optional[Union[str, List, Dict]] = None,
         download_config: Optional[DownloadConfig] = None,
-        download_mode: Optional[DownloadMode] = None,
+        download_mode: Optional[Union[DownloadMode, str]] = None,
     ):
-
         self.name = name
         self.data_files = data_files
         self.data_dir = data_dir
@@ -741,9 +743,8 @@ class HubDatasetModuleFactoryWithoutScript(_DatasetModuleFactory):
         data_dir: Optional[str] = None,
         data_files: Optional[Union[str, List, Dict]] = None,
         download_config: Optional[DownloadConfig] = None,
-        download_mode: Optional[DownloadMode] = None,
+        download_mode: Optional[Union[DownloadMode, str]] = None,
     ):
-
         self.name = name
         self.revision = revision
         self.data_files = data_files
@@ -852,7 +853,7 @@ class HubDatasetModuleFactoryWithScript(_DatasetModuleFactory):
         name: str,
         revision: Optional[Union[str, Version]] = None,
         download_config: Optional[DownloadConfig] = None,
-        download_mode: Optional[DownloadMode] = None,
+        download_mode: Optional[Union[DownloadMode, str]] = None,
         dynamic_modules_path: Optional[str] = None,
     ):
         self.name = name
@@ -1045,7 +1046,7 @@ def dataset_module_factory(
     path: str,
     revision: Optional[Union[str, Version]] = None,
     download_config: Optional[DownloadConfig] = None,
-    download_mode: Optional[DownloadMode] = None,
+    download_mode: Optional[Union[DownloadMode, str]] = None,
     dynamic_modules_path: Optional[str] = None,
     data_dir: Optional[str] = None,
     data_files: Optional[Union[Dict, List, str, DataFilesDict]] = None,
@@ -1083,7 +1084,7 @@ def dataset_module_factory(
             As datasets have their own git repository on the Datasets Hub, the default version "main" corresponds to their "main" branch.
             You can specify a different version than the default "main" by using a commit SHA or a git tag of the dataset repository.
         download_config (:class:`DownloadConfig`, optional): Specific download configuration parameters.
-        download_mode (:class:`DownloadMode`, default ``REUSE_DATASET_IF_EXISTS``): Download/generate mode.
+        download_mode (:class:`DownloadMode` or :obj:`str`, default ``REUSE_DATASET_IF_EXISTS``): Download/generate mode.
         dynamic_modules_path (Optional str, defaults to HF_MODULES_CACHE / "datasets_modules", i.e. ~/.cache/huggingface/modules/datasets_modules):
             Optional path to the directory in which the dynamic modules are saved. It must have been initialized with :obj:`init_dynamic_modules`.
             By default, the datasets and metrics are stored inside the `datasets_modules` module.
@@ -1178,8 +1179,7 @@ def dataset_module_factory(
                     msg = f"Dataset '{path}' doesn't exist on the Hub"
                     msg = msg + f" at revision '{revision}'" if revision else msg
                     raise FileNotFoundError(
-                        msg
-                        + ". If the repo is private, make sure you are authenticated with `use_auth_token=True` after logging in with `huggingface-cli login`."
+                        msg + ". If the repo is private or gated, make sure to log in with `huggingface-cli login`."
                     )
                 else:
                     raise e
@@ -1200,7 +1200,9 @@ def dataset_module_factory(
                     download_config=download_config,
                     download_mode=download_mode,
                 ).get_module()
-        except Exception as e1:  # noqa: all the attempts failed, before raising the error we should check if the module is already cached.
+        except (
+            Exception
+        ) as e1:  # noqa: all the attempts failed, before raising the error we should check if the module is already cached.
             try:
                 return CachedDatasetModuleFactory(path, dynamic_modules_path=dynamic_modules_path).get_module()
             except Exception as e2:  # noqa: if it's not in the cache, then it doesn't exist.
@@ -1225,7 +1227,7 @@ def metric_module_factory(
     path: str,
     revision: Optional[Union[str, Version]] = None,
     download_config: Optional[DownloadConfig] = None,
-    download_mode: Optional[DownloadMode] = None,
+    download_mode: Optional[Union[DownloadMode, str]] = None,
     dynamic_modules_path: Optional[str] = None,
     **download_kwargs,
 ) -> MetricModule:
@@ -1258,7 +1260,7 @@ def metric_module_factory(
             - it will also try to load it from the main branch if it's not available at the local version of the lib.
             Specifying a version that is different from your local version of the lib might cause compatibility issues.
         download_config (:class:`DownloadConfig`, optional): Specific download configuration parameters.
-        download_mode (:class:`DownloadMode`, default ``REUSE_DATASET_IF_EXISTS``): Download/generate mode.
+        download_mode (:class:`DownloadMode` or :obj:`str`, default ``REUSE_DATASET_IF_EXISTS``): Download/generate mode.
         dynamic_modules_path (Optional str, defaults to HF_MODULES_CACHE / "datasets_modules", i.e. ~/.cache/huggingface/modules/datasets_modules):
             Optional path to the directory in which the dynamic modules are saved. It must have been initialized with :obj:`init_dynamic_modules`.
             By default, the datasets and metrics are stored inside the `datasets_modules` module.
@@ -1303,7 +1305,9 @@ def metric_module_factory(
                     download_mode=download_mode,
                     dynamic_modules_path=dynamic_modules_path,
                 ).get_module()
-            except Exception as e1:  # noqa: all the attempts failed, before raising the error we should check if the module is already cached.
+            except (
+                Exception
+            ) as e1:  # noqa: all the attempts failed, before raising the error we should check if the module is already cached.
                 try:
                     return CachedMetricModuleFactory(path, dynamic_modules_path=dynamic_modules_path).get_module()
                 except Exception as e2:  # noqa: if it's not in the cache, then it doesn't exist.
@@ -1327,7 +1331,7 @@ def load_metric(
     experiment_id: Optional[str] = None,
     keep_in_memory: bool = False,
     download_config: Optional[DownloadConfig] = None,
-    download_mode: Optional[DownloadMode] = None,
+    download_mode: Optional[Union[DownloadMode, str]] = None,
     revision: Optional[Union[str, Version]] = None,
     **metric_init_kwargs,
 ) -> Metric:
@@ -1355,7 +1359,7 @@ def load_metric(
             This is useful to compute metrics in distributed setups (in particular non-additive metrics like F1).
         keep_in_memory (bool): Whether to store the temporary results in memory (defaults to False)
         download_config (Optional ``datasets.DownloadConfig``: specific download configuration parameters.
-        download_mode (:class:`DownloadMode`, default ``REUSE_DATASET_IF_EXISTS``): Download/generate mode.
+        download_mode (:class:`DownloadMode` or :obj:`str`, default ``REUSE_DATASET_IF_EXISTS``): Download/generate mode.
         revision (Optional ``Union[str, datasets.Version]``): if specified, the module will be loaded from the datasets repository
             at this version. By default, it is set to the local version of the lib. Specifying a version that is different from
             your local version of the lib might cause compatibility issues.
@@ -1405,7 +1409,7 @@ def load_dataset_builder(
     cache_dir: Optional[str] = None,
     features: Optional[Features] = None,
     download_config: Optional[DownloadConfig] = None,
-    download_mode: Optional[DownloadMode] = None,
+    download_mode: Optional[Union[DownloadMode, str]] = None,
     revision: Optional[Union[str, Version]] = None,
     use_auth_token: Optional[Union[bool, str]] = None,
     **config_kwargs,
@@ -1459,7 +1463,7 @@ def load_dataset_builder(
             Set the features type to use for this dataset.
         download_config ([`DownloadConfig`], *optional*):
             Specific download configuration parameters.
-        download_mode ([`DownloadMode`], defaults to `REUSE_DATASET_IF_EXISTS`):
+        download_mode ([`DownloadMode`] or `str`, defaults to `REUSE_DATASET_IF_EXISTS`):
             Download/generate mode.
         revision ([`Version`] or `str`, *optional*):
             Version of the dataset script to load.
@@ -1539,8 +1543,9 @@ def load_dataset(
     cache_dir: Optional[str] = None,
     features: Optional[Features] = None,
     download_config: Optional[DownloadConfig] = None,
-    download_mode: Optional[DownloadMode] = None,
-    ignore_verifications: bool = False,
+    download_mode: Optional[Union[DownloadMode, str]] = None,
+    verification_mode: Optional[Union[VerificationMode, str]] = None,
+    ignore_verifications="deprecated",
     keep_in_memory: Optional[bool] = None,
     save_infos: bool = False,
     revision: Optional[Union[str, Version]] = None,
@@ -1627,14 +1632,25 @@ def load_dataset(
             Set the features type to use for this dataset.
         download_config ([`DownloadConfig`], *optional*):
             Specific download configuration parameters.
-        download_mode ([`DownloadMode`], defaults to `REUSE_DATASET_IF_EXISTS`):
+        download_mode ([`DownloadMode`] or `str`, defaults to `REUSE_DATASET_IF_EXISTS`):
             Download/generate mode.
+        verification_mode ([`VerificationMode`] or `str`, defaults to `BASIC_CHECKS`):
+            Verification mode determining the checks to run on the downloaded/processed dataset information (checksums/size/splits/...).
+
+            <Added version="2.9.1"/>
         ignore_verifications (`bool`, defaults to `False`):
             Ignore the verifications of the downloaded/processed dataset information (checksums/size/splits/...).
+
+            <Deprecated version="2.9.1">
+
+            `ignore_verifications` was deprecated in version 2.9.1 and will be removed in 3.0.0.
+            Please use `verification_mode` instead.
+
+            </Deprecated>
         keep_in_memory (`bool`, defaults to `None`):
             Whether to copy the dataset in-memory. If `None`, the dataset
             will not be copied in-memory unless explicitly enabled by setting `datasets.config.IN_MEMORY_MAX_SIZE` to
-            nonzero. See more details in the [improve performance](./cache#improve-performance) section.
+            nonzero. See more details in the [improve performance](../cache#improve-performance) section.
         save_infos (`bool`, defaults to `False`):
             Save the dataset information (checksums/size/splits/...).
         revision ([`Version`] or `str`, *optional*):
@@ -1655,9 +1671,9 @@ def load_dataset(
             like rar and xz are not yet supported. The tgz format doesn't allow streaming.
         num_proc (`int`, *optional*, defaults to `None`):
             Number of processes when downloading and generating the dataset locally.
-                Multiprocessing is disabled by default.
+            Multiprocessing is disabled by default.
 
-                <Added version="2.7.0"/>
+            <Added version="2.7.0"/>
         **config_kwargs (additional keyword arguments):
             Keyword arguments to be passed to the `BuilderConfig`
             and used in the [`DatasetBuilder`].
@@ -1715,6 +1731,13 @@ def load_dataset(
     >>> ds = load_dataset('imagefolder', data_dir='/path/to/images', split='train')
     ```
     """
+    if ignore_verifications != "deprecated":
+        verification_mode = "none" if ignore_verifications else "full"
+        warnings.warn(
+            "'ignore_verifications' was deprecated in favor of 'verification_mode' in version 2.9.1 and will be removed in 3.0.0.\n"
+            "To ignore verifications, you can pass `verification_mode='no_checks'` instead.",
+            FutureWarning,
+        )
     if Path(path, config.DATASET_STATE_JSON_FILENAME).exists():
         raise ValueError(
             "You are trying to load a dataset that was saved using `save_to_disk`. "
@@ -1728,7 +1751,9 @@ def load_dataset(
         )
 
     download_mode = DownloadMode(download_mode or DownloadMode.REUSE_DATASET_IF_EXISTS)
-    ignore_verifications = ignore_verifications or save_infos
+    verification_mode = VerificationMode(
+        (verification_mode or VerificationMode.BASIC_CHECKS) if not save_infos else VerificationMode.ALL_CHECKS
+    )
 
     # Create a dataset builder
     builder_instance = load_dataset_builder(
@@ -1757,7 +1782,7 @@ def load_dataset(
     builder_instance.download_and_prepare(
         download_config=download_config,
         download_mode=download_mode,
-        ignore_verifications=ignore_verifications,
+        verification_mode=verification_mode,
         try_from_hf_gcs=try_from_hf_gcs,
         num_proc=num_proc,
     )
@@ -1766,7 +1791,7 @@ def load_dataset(
     keep_in_memory = (
         keep_in_memory if keep_in_memory is not None else is_small_dataset(builder_instance.info.dataset_size)
     )
-    ds = builder_instance.as_dataset(split=split, ignore_verifications=ignore_verifications, in_memory=keep_in_memory)
+    ds = builder_instance.as_dataset(split=split, verification_mode=verification_mode, in_memory=keep_in_memory)
     # Rename and cast features to match task schema
     if task is not None:
         ds = ds.prepare_for_task(task)
@@ -1776,7 +1801,9 @@ def load_dataset(
     return ds
 
 
-def load_from_disk(dataset_path: str, fs=None, keep_in_memory: Optional[bool] = None) -> Union[Dataset, DatasetDict]:
+def load_from_disk(
+    dataset_path: str, fs="deprecated", keep_in_memory: Optional[bool] = None, storage_options: Optional[dict] = None
+) -> Union[Dataset, DatasetDict]:
     """
     Loads a dataset that was previously saved using [`~Dataset.save_to_disk`] from a dataset directory, or
     from a filesystem using either [`~datasets.filesystems.S3FileSystem`] or any implementation of
@@ -1787,12 +1814,25 @@ def load_from_disk(dataset_path: str, fs=None, keep_in_memory: Optional[bool] =
             Path (e.g. `"dataset/train"`) or remote URI (e.g.
             `"s3://my-bucket/dataset/train"`) of the [`Dataset`] or [`DatasetDict`] directory where the dataset will be
             loaded from.
-        fs (`~filesystems.S3FileSystem` or `fsspec.spec.AbstractFileSystem`, *optional*, defaults to `None`):
+        fs (`~filesystems.S3FileSystem` or `fsspec.spec.AbstractFileSystem`, *optional*):
             Instance of the remote filesystem used to download the files from.
+
+            <Deprecated version="2.9.0">
+
+            `fs` was deprecated in version 2.9.0 and will be removed in 3.0.0.
+            Please use `storage_options` instead, e.g. `storage_options=fs.storage_options`.
+
+            </Deprecated>
+
         keep_in_memory (`bool`, defaults to `None`):
             Whether to copy the dataset in-memory. If `None`, the dataset
             will not be copied in-memory unless explicitly enabled by setting `datasets.config.IN_MEMORY_MAX_SIZE` to
-            nonzero. See more details in the [improve performance](./cache#improve-performance) section.
+            nonzero. See more details in the [improve performance](../cache#improve-performance) section.
+
+        storage_options (`dict`, *optional*):
+            Key/value pairs to be passed on to the file-system backend, if any.
+
+            <Added version="2.9.0"/>
 
     Returns:
         [`Dataset`] or [`DatasetDict`]:
@@ -1806,19 +1846,32 @@ def load_from_disk(dataset_path: str, fs=None, keep_in_memory: Optional[bool] =
     >>> ds = load_from_disk('path/to/dataset/directory')
     ```
     """
+    if fs != "deprecated":
+        warnings.warn(
+            "'fs' was deprecated in favor of 'storage_options' in version 2.9.0 and will be removed in 3.0.0.\n"
+            "You can remove this warning by passing 'storage_options=fs.storage_options' instead.",
+            FutureWarning,
+        )
+        storage_options = fs.storage_options
+
+    fs_token_paths = fsspec.get_fs_token_paths(dataset_path, storage_options=storage_options)
+    fs: fsspec.AbstractFileSystem = fs_token_paths[0]
+
     # gets filesystem from dataset, either s3:// or file:// and adjusted dataset_path
     if is_remote_filesystem(fs):
         dest_dataset_path = extract_path_from_uri(dataset_path)
+        path_join = posixpath.join
     else:
         fs = fsspec.filesystem("file")
         dest_dataset_path = dataset_path
+        path_join = os.path.join
 
     if not fs.exists(dest_dataset_path):
         raise FileNotFoundError(f"Directory {dataset_path} not found")
-    if fs.isfile(Path(dest_dataset_path, config.DATASET_INFO_FILENAME).as_posix()):
-        return Dataset.load_from_disk(dataset_path, fs, keep_in_memory=keep_in_memory)
-    elif fs.isfile(Path(dest_dataset_path, config.DATASETDICT_JSON_FILENAME).as_posix()):
-        return DatasetDict.load_from_disk(dataset_path, fs, keep_in_memory=keep_in_memory)
+    if fs.isfile(path_join(dest_dataset_path, config.DATASET_INFO_FILENAME)):
+        return Dataset.load_from_disk(dataset_path, keep_in_memory=keep_in_memory, storage_options=storage_options)
+    elif fs.isfile(path_join(dest_dataset_path, config.DATASETDICT_JSON_FILENAME)):
+        return DatasetDict.load_from_disk(dataset_path, keep_in_memory=keep_in_memory, storage_options=storage_options)
     else:
         raise FileNotFoundError(
             f"Directory {dataset_path} is neither a dataset directory nor a dataset dict directory."
