@@ -62,7 +62,6 @@ class FolderBasedBuilder(datasets.GeneratorBasedBuilder):
     EXTENSIONS: List[str]
     CLASSIFICATION_TASK: TaskTemplate
 
-    SKIP_CHECKSUM_COMPUTATION_BY_DEFAULT: bool = True
     METADATA_FILENAMES: List[str] = ["metadata.csv", "metadata.jsonl"]
 
     def _info(self):
@@ -134,7 +133,7 @@ class FolderBasedBuilder(datasets.GeneratorBasedBuilder):
 
                 if metadata_files:
                     # add metadata if `metadata_files` are found and `drop_metadata` is None (default) or False
-                    add_metadata = not (self.config.drop_metadata is True)
+                    add_metadata = not self.config.drop_metadata
                     # if `metadata_files` are found, add labels only if
                     # `drop_labels` is set up to False explicitly (not-default behavior)
                     add_labels = self.config.drop_labels is False
